@@ -10,7 +10,7 @@ use Mojo::Exception;
 use Mojolicious::Plugin::Ident::Response;
 
 # ABSTRACT: Mojolicious plugin to interact with a remote ident service
-our $VERSION = '0.30'; # VERSION
+our $VERSION = '0.31'; # VERSION
 
 
 sub register
@@ -126,13 +126,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Mojolicious::Plugin::Ident - Mojolicious plugin to interact with a remote ident service
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
@@ -320,7 +322,7 @@ With a callback (non-blocking):
    my $self = shift;
    $self->ident_same_user(sub {
      my $same_user = shift;
-     $same_user ? $self->render(text => 'private text') : $self->render_not_found;
+     $same_user ? $self->render(text => 'private text') : $self->reply->not_found;
    });
  }
 
@@ -375,7 +377,7 @@ same behavior in both new and old versions of L<Mojolicious>:
    if($self->ident_same_user) {
      return 0;
    } else {
-     $self->render_not_found;
+     $self->reply->not_found;
      return 1;
    }
  };
